## 📖 Melhorias para hoje 
- [] adicionar timestamp ao armazenar o input e output
- [] adicionar Hash256 com base nos timestamp que o input e output foram armazenados, Hash em destilação de agentes ``no tipo json ``
- [] adicionar Armazenamento e contabilizacao dos tokens de consumo de cada repositorio criado


